summaryrefslogtreecommitdiff
path: root/SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c
diff options
context:
space:
mode:
authorChao Zhang <chao.b.zhang@intel.com>2016-01-15 05:26:04 +0000
committerczhang46 <czhang46@Edk2>2016-01-15 05:26:04 +0000
commit623538ff98be113c0f3cc12bcadbdfe5466dc5ca (patch)
tree9a7dd154f558ce5735ddd22c24ee45c0992743e6 /SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c
parent02dd6af921a39adc2097ebfcd2b8d4b1ec82e0db (diff)
downloadedk2-623538ff98be113c0f3cc12bcadbdfe5466dc5ca.zip
edk2-623538ff98be113c0f3cc12bcadbdfe5466dc5ca.tar.gz
edk2-623538ff98be113c0f3cc12bcadbdfe5466dc5ca.tar.bz2
SecurityPkg: SecureBootConfigDxe: Fix string typo
Fix secure boot mode transition string typo. Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Chao Zhang <chao.b.zhang@intel.com> Reviewed-by: Qin Long <qin.long@intel.com> Reviewed-by: Fu Siyuan <siyuan.fu@intel.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@19646 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c')
-rw-r--r--SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c b/SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c
index aafb3b3..e0f934b 100644
--- a/SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c
+++ b/SecurityPkg/VariableAuthenticated/SecureBootConfigDxe/SecureBootConfigImpl.c
@@ -3463,7 +3463,7 @@ SecureBootCallback (
mIsEnterSecureBootForm = TRUE;
} else if (QuestionId == KEY_TRANS_SECURE_BOOT_MODE){
//
// Secure Boot Policy variable changes after tranistion. Re-sync CurSecureBootMode
//
ExtractSecureBootModeFromVariable(&IfrNvData->CurSecureBootMode);
mIsSelectedSecureBootModeForm = TRUE;
@@ -3752,7 +3752,7 @@ SecureBootCallback (
CreatePopUp (
EFI_LIGHTGRAY | EFI_BACKGROUND_BLUE,
&Key,
- L"Secure boot mode tranistion requires PK change",
+ L"Secure boot mode transition requires PK change",
L"Please go to link below to update PK",
NULL
);
@@ -3763,7 +3763,7 @@ SecureBootCallback (
Status = SecureBootModeTransition(IfrNvData->CurSecureBootMode, Value->u8);
//
// Secure Boot Policy variable may change after tranistion. Re-sync CurSecureBootMode
//
ExtractSecureBootModeFromVariable(&CurSecureBootMode);
if (IfrNvData->CurSecureBootMode != CurSecureBootMode) {
@@ -3463,7 +3463,7 @@ SecureBootCallback (
} else if (QuestionId == KEY_TRANS_SECURE_BOOT_MODE){
//
- // Secure Boot Policy variable changes after tranistion. Re-sync CurSecureBootMode
+ // Secure Boot Policy variable changes after transition. Re-sync CurSecureBootMode
//
ExtractSecureBootModeFromVariable(&IfrNvData->CurSecureBootMode);
@@ -3763,7 +3763,7 @@ SecureBootCallback (
Status = SecureBootModeTransition(IfrNvData->CurSecureBootMode, Value->u8);
//
- // Secure Boot Policy variable may change after tranistion. Re-sync CurSecureBootMode
+ // Secure Boot Policy variable may change after transition. Re-sync CurSecureBootMode
//
ExtractSecureBootModeFromVariable(&CurSecureBootMode);